#include <cstdlib>
#include <iostream>
#include <stdlib.h>
#include <math.h>
#include <stdio.h>

#define PRECISION 40
#define MAXN 100

using namespace std;

/*
branchFactor() receives in input a branching vector
It returns the corresponding branching factor "bf"
This is done via doubling + binary search. The desired value satisfies 
1-sum_{j=0}^{n-1}bf^(-V[i])=0
The binary search is anyway interrupted when the value is accurate enough 
*/
double branchFactor(int n, double* V){

  double left=0.0;
  double right=1.0;
  double f;
  //we compute an upper bound right on the branching factor via doubling
  do{
    right = right*2;   
    f=1.0;
    for(int j=0; j<n; j++) {
      f -= pow(right, -V[j]);
    }          
  }while(f<=0);       
  //we compute the branching factor via binary search
  double bf;
  for(int i=0; i<PRECISION; i++) {
    bf = (left+right)/2.0;
    f=1.0;
    for(int j=0; j<n; j++) {
      f -= pow(bf, -V[j]);
    }
    if(f==0) return bf;
    if(f>0) right = bf;
    else left = bf;
  }
  return right;//this way we return an upper bound            
}


int main() {

  int n;
  double V[MAXN];
  double d;

  while(1) {
    cout << endl << "# of branchings:";
    cin >> n;
    if(n<=0 || n>MAXN) exit(1);

    for(int i=0; i<n; i++) {
      cout << "delta(" << i << "):";
      cin >> d;
      if(d<0) exit(1);
      V[i]=d;
    }

    double bf = branchFactor(n, V);
    printf("bf=%.8f (%.8f)\n", bf, log(bf)/log(2));
  }
  return 0;
}
